@@ -1621,6 +1621,24 @@ UBX_PAYLOADS_GET = {
             },
         ),
     },
+    "RXM-RAW": {
+        "iTOW": I4,
+        "week": I2,
+        "numSV": U1,
+        "reserved1": U1,
+        "group": (
+            "numSV",
+            {  # repeating group * numSV
+                "cpMes": R8,
+                "prMes": R8,
+                "doMes": R4,
+                "sv": U1,
+                "mesQI": I1,
+                "cno": I1,
+                "lli": U1,
+            },
+        ),
+    },
     "RXM-RAWX": {
         "rcvTow": R8,
         "week": U2,
@@ -1628,20 +1646,25 @@ UBX_PAYLOADS_GET = {
         "numMeas": U1,
         "recStat": X1,
         "reserved1": U3,
-        "prMes": R8,
-        "cpMes": R8,
-        "doMes": R4,
-        "gnssId": U1,
-        "svId": U1,
-        "reserved2": U1,
-        "freqId": U1,
-        "locktime": U2,
-        "cno": U1,
-        "prStdev": X1,
-        "cpStdev": X1,
-        "doStdev": X1,
-        "trkStat": X1,
-        "reserved3": U1,
+        "group": (
+            "numMeas",
+            {  # repeating group * numMeas
+                "prMes": R8,
+                "cpMes": R8,
+                "doMes": R4,
+                "gnssId": U1,
+                "svId": U1,
+                "reserved2": U1,
+                "freqId": U1,
+                "locktime": U2,
+                "cno": U1,
+                "prStdev": X1,
+                "cpStdev": X1,
+                "doStdev": X1,
+                "trkStat": X1,
+                "reserved3": U1,
+            },
+        ),
     },
     "RXM-RLM-S": {
         "version": U1,  # 0x00
